@@ -1,15 +1,13 @@
 ﻿#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import time, re, os
-from PyQt4 import QtWebKit, QtCore, QtGui
-from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest, QNetworkReply, QNetworkProxy, QNetworkCookieJar
+import os
+from PyQt4 import QtWebKit, QtCore
+from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest, QNetworkReply
 
 class QonsoExtractor:
-   def __init__(self, view):
+   def __init__(self):
       self.debug = os.environ.has_key('DEBUG')
-      self.view = view
-      self.SetStatus('INFO', "Initialisation...")
       self.page = QtWebKit.QWebPage()
       self.frame = self.page.currentFrame()
       self.urlconso = ""
@@ -18,6 +16,10 @@ class QonsoExtractor:
       self.hostname = ""
       self.login = ""
       self.password = ""
+      self.model = None
+      
+   def SetView(self, view):
+      self.view = view
       
    def SetLogin(self, login):
       self.login = login
@@ -50,20 +52,18 @@ class QonsoExtractor:
       if not self.login or not self.password:
          return
 
+      self.SetStatus('INFO', 'Connection au site...')
+      
       self.Debug(self.login)
       self.Debug(self.password)
       
       self.manager = QNetworkAccessManager()
-
-      self.SetStatus('INFO', 'Connection au site...')
+      QtCore.QObject.connect(self.manager, QtCore.SIGNAL("finished(QNetworkReply *)"), self.readResponse )
 
       request = QNetworkRequest()
       request.setUrl( QtCore.QUrl(self.urlbeforeAuth ) ) 
       self.manager.get(request)
-      
       self.authentication = 'Init'
-      
-      QtCore.QObject.connect(self.manager, QtCore.SIGNAL("finished(QNetworkReply *)"), self.readResponse )
 
    def Authenticate(self, idCorrelation):
       pass
@@ -89,3 +89,22 @@ class QonsoExtractor:
    def ExtractDatas(self, datas):
       pass
 
+   def PrepareRequest(self):
+      request = QNetworkRequest()
+      request.setUrl( QtCore.QUrl(self.urlAuth) ) 
+      request.setHeader(QNetworkRequest.ContentTypeHeader, "application/x-www-form-urlencoded")
+      request.setRawHeader("Connection", "keep-alive")
+      request.setRawHeader("Keep-Alive", "115");
+      request.setRawHeader("Referer", self.urlbeforeAuth)
+      request.setRawHeader("Host", self.hostname)
+      return request
+
+   def PostRequest(self, params, request=None):
+      postData = QtCore.QByteArray()
+      postData.append(params.toString()[1:])
+
+      if not request:
+         request = self.PrepareRequest()
+
+      request.setRawHeader("Content-Length", "%s" % postData.length() )
+      self.manager.post(request, postData)
