@@ -1,11 +1,9 @@
 ﻿#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import sys, os
-import ConfigParser
+import os
 from PyQt4 import QtGui, QtCore
-from QonsoExtractorBouygues import QonsoExtractorBouygues
-from QonsoExtractorSFR import QonsoExtractorSFR
+import QonsoFactory
 from QonsoModel import QonsoModel
 from DlgConfig import DlgConfig
 from WProgress import WProgress
@@ -29,18 +27,18 @@ class QonsoView(QtGui.QMainWindow):
       self.config = DlgConfig()
       self.model = QonsoModel()
       
+      self.credentialsOk = False
+      
       if not self.config.GetLogin() or not self.config.GetPassword() or not self.config.GetOperator():
          self.config.AskForCredentials()
-
+      
       self.CreateExtractor()
       
-      self.credentialsOk = False
       self.layoutsOK = False
       self.centralWidget = QtGui.QWidget()
 
       self.vbox = QtGui.QVBoxLayout()
       self.centralWidget.setLayout(self.vbox)
-      
       self.setCentralWidget( self.centralWidget )
 
       self.credentialsOk = True
@@ -48,21 +46,18 @@ class QonsoView(QtGui.QMainWindow):
       if not self.offline:
          self.extractor.InitAuthenticate()
       else:
-         f = open(r"..\..\..\data\SFR.htm", "r")
+         f = open(r"..\..\..\data\Bouygues.html", "r")
          self.extractor.ExtractDatas( f.read() )
          f.close()
 
-      
-   def CreateExtractor(self):
-      if self.config.GetOperator()=='SFR':
-         self.extractor = QonsoExtractorSFR(self)
-      elif self.config.GetOperator()=='Bouygues Telecom':
-         self.extractor = QonsoExtractorBouygues(self)
 
+   def CreateExtractor(self):
+      self.extractor = QonsoFactory.CreateExtractor( self.config.GetOperator() )
+      self.extractor.SetView(self)
       self.extractor.SetLogin(self.config.GetLogin())
       self.extractor.SetPassword(self.config.GetPassword())
       self.extractor.SetModel(self.model)
-
+      
    def Settings(self):
       self.config.AskForCredentials()
       self.credentialsOk = True
